@@ -58,6 +58,7 @@ tar_files_input <- function(
   files,
   batches = length(files),
   format = c("file", "url", "aws_file"),
+  repository = targets::tar_option_get("repository"),
   iteration = targets::tar_option_get("iteration"),
   error = targets::tar_option_get("error"),
   memory = targets::tar_option_get("memory"),
@@ -73,6 +74,7 @@ tar_files_input <- function(
     files = files,
     batches = batches,
     format = format,
+    repository = repository,
     iteration = iteration,
     error = error,
     memory = memory,
